@@ -144,7 +144,7 @@ vcov.polr <- function(object, ...)
     if(is.null(object$Hessian)) {
         message("\nRe-fitting to get Hessian\n")
 	utils::flush.console()
-        object <- update(object, Hess=TRUE,
+        object <- update(object, Hess = TRUE,
                          start = c(object$coefficients, object$zeta))
     }
     vc <- ginv(object$Hessian)
@@ -436,7 +436,7 @@ profile.polr <- function(fitted, which = 1L:p, alpha = 0.01,
         }
         si <- order(zi)
         prof[[pi]] <- structure(data.frame(zi[si]), names = profName)
-        prof[[pi]]$par.vals <- pvi[si, ]
+        prof[[pi]]$par.vals <- pvi[si, , drop = FALSE]
     }
     val <- structure(prof, original.fit = fitted, summary = summ)
     class(val) <- c("profile.polr", "profile")
@@ -478,7 +478,10 @@ confint.profile.polr <-
 }
 
 logLik.polr <- function(object, ...)
-    structure(-0.5 * object$deviance, df = object$edf, class = "logLik")
+    structure(-0.5 * object$deviance, df = object$edf,
+              nobs = object[["nobs"]], class = "logLik")
+
+nobs.polr <- function(object, ...) object[["nobs"]]
 
 simulate.polr <- function(object, nsim = 1, seed = NULL, ...)
 {
