@@ -7,7 +7,7 @@
 library(MASS)
 options(width=65, digits=5, height=9999)
 options(contrasts=c("contr.treatment", "contr.poly"))
-postscript("ch13.ps", width=8, height=6, pointsize=9)
+pdf("ch13.pdf", width=8, height=6, pointsize=9)
 
 library(survival)
 
